////////////////////////////////////////////////////////////////////////////////
//
// The contents of this file are subject to the terms of the Common Development
// and Distribution License(the License).  You may not use this file except in
// compliance with the License.
//
// You may obtain a copy of the License from:
// http://www.opensource.org/licenses/cddl1.txt
// See the License for the specific language governing
// permissions and limitations under the License.
//
// Copyright (c) 2007, Java Spnego Development Team.
// (http://spnego.dev.java.net/servlets/ProjectMemberList) All Rights Reserved.
//
////////////////////////////////////////////////////////////////////////////////

package net.java.spnego;

import java.security.Principal;
import java.util.logging.Logger;
import java.util.logging.Level;
import javax.security.auth.Subject;
import javax.security.auth.message.AuthException;
import javax.security.auth.message.MessageInfo;
import org.ietf.jgss.GSSContext;

/**
 * This JMAC Module supports the SPNEGO mechanism.
 * <p/>
 * Kerberos is implemented but not NTLM, yet.
 * <p/>
 * This module must be configured in Glassfish to take effect.
 *
 * A new instance of this class is created for each call,
 * so slow set up of resources within this class should be avoided.
 *
 *
 * @author Greg Luck
 * @version $Id: TestLoginModule.java 0 Feb 28, 2007 10:11:43 PM dwhitla $
 * @see javax.security.auth.message.MessageInfo
 * @see javax.security.auth.Subject
 */
public class ExampleSpnegoServerAuthModule extends SpnegoServerAuthModule {

    private static final Logger LOG = Logger.getLogger(ExampleSpnegoServerAuthModule.class.getName());



    /**
     * Provides a list of group names to apply to the calling principal.
     *
     * This implementation adds all callers to all groups
     *
     * This method is called as of Glassfish V2 Build 41 each time resources with a security
     * constraint is called. Accordinly, this method should be very performant. A new instance
     * of this class is created for each call, so slow set up of resources within this class should be avoided.
     *
     * @param caller the calling principal. The Kerberos user.
     * @return an array of group names.
     */
    @Override
    public String[] getGroupsForCaller(MessageInfo messageInfo, GSSContext gssContext
            ) throws AuthException {
        LOG.log(Level.FINE, "Get groups");
        return new String[] {"authenticated", "allowed"};
    }
}
