package net.java.spnego.pac;

import java.io.ByteArrayInputStream;
import java.io.DataInputStream;
import java.io.IOException;

public class Pac {

    public static final int PAC_VERSION = 0;
    public static final int LOGON_INFO = 1;
    public static final int CREDENTIAL_TYPE = 2;
    public static final int SERVER_CHECKSUM = 6;
    public static final int PRIVSVR_CHECKSUM = 7;
    public static final int LOGON_EXTRA_SIDS = 0x20;
    public static final int LOGON_RESOURCE_GROUPS = 0x200;
    public static final long FILETIME_BASE = -11644473600000L;
    public static final int MD5_KRB_SALT = 17;
    public static final int MD5_BLOCK_LENGTH = 64;

    private PacLogonInfo logonInfo;

    public Pac(byte[] data) throws IOException {
        PacDataInputStream pacStream = new PacDataInputStream(new DataInputStream(
                new ByteArrayInputStream(data)));

        if (data.length <= 8) {
            throw new IOException("pac.token.empty");
        }

        int bufferCount = pacStream.readInt();
        int version = pacStream.readInt();

        if (version != Pac.PAC_VERSION) {
            throw new IOException("pac.version.invalid");
        }

        for (int bufferIndex = 0; bufferIndex < bufferCount; bufferIndex++) {
            int bufferType = pacStream.readInt();
            int bufferSize = pacStream.readInt();
            long bufferOffset = pacStream.readLong();
            byte[] bufferData = new byte[bufferSize];
            System.arraycopy(data, (int) bufferOffset, bufferData, 0, bufferSize);

            switch (bufferType) {
                case Pac.LOGON_INFO:
                    // PAC Credential Information
                    logonInfo = new PacLogonInfo(bufferData);
                    break;
                default:
            }
        }
    }

    public PacLogonInfo getLogonInfo() {
        return logonInfo;
    }

}
